/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * CameraTargetData.cpp
 *
 *  Created on: Aug 6, 2009
 *      Author: jwienke
 */

#include "CameraTargetData.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

std::string CameraTargetData::getBaseTag() {
	return "CAMERATARGET";
}

std::string CameraTargetData::getTemplate() {
	return std::string("<") + getBaseTag() + "><GENERATOR/>"
			+ Timestamp::getTemplate()
			+ "<CYLINDRIC dist=\"\" height=\"\"/>"
			+ "<AZIMUTH rad=\"\" />"
			+ "<ZOOM qual=\"\" />" + "</" + getBaseTag() + ">";
}

CameraTargetData::CameraTargetData() :
	Type("unknown") {
}

double CameraTargetData::getDistance() const {
	return distance;
}

void CameraTargetData::setDistance(double distance) {
	this->distance = distance;
}

double CameraTargetData::getHeight() const {
	return height;
}

void CameraTargetData::setHeight(double height) {
	this->height = height;
}

double CameraTargetData::getAzimuth() const {
	return azimuth;
}

void CameraTargetData::setAzimuth(double azimuth) {
	this->azimuth = azimuth;
}

double CameraTargetData::getZoom() const {
	return zoom;
}

void CameraTargetData::setZoom(double zoom) {
	this->zoom = zoom;
}

void CameraTargetData::sanitizeLocation(xmltio::Location &loc) const {
	
}

void CameraTargetData::fillInto(xmltio::Location &loc) const {

	Type::fillInto(loc);

	loc[XPath("CYLINDRIC/@dist")] = getDistance();
	loc[XPath("CYLINDRIC/@height")] = getHeight();

	loc[XPath("AZIMUTH/@rad")] = getAzimuth();

	loc[XPath("ZOOM/@qual")] = getZoom();

}

void CameraTargetData::fromLocation(const xmltio::Location &loc_, CameraTargetData &ctd) {

	Type::fromLocation(loc_, ctd);

	ctd.setDistance(extract<double> (loc_[XPath("CYLINDRIC/@dist")]));
	ctd.setHeight(extract<double> (loc_[XPath("CYLINDRIC/@height")]));

	ctd.setAzimuth(extract<double> (loc_[XPath("AZIMUTH/@rad")]));

	ctd.setZoom(extract<double> (loc_[XPath("ZOOM/@qual")]));

}
