/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * KatanaPoseData.h
 *
 *  Created on: May 25, 2010
 *      Author: ttoenige
 */

#ifndef KATANAPOSEDATA_H_
#define KATANAPOSEDATA_H_

#include "Type.h"
namespace airobots
{

class KatanaPoseData: public Type
{
public:
	static std::string getBaseTag();

	static std::string getTemplate();

	/**
	 * Returns the x-value of the endeffector position (mm)
	 */
	double getX() const;
	void setX(double x);

	/**
	 * Returns the y-value of the endeffector position (mm)
	 */
	double getY() const;
	void setY(double y);

	/**
	 * Returns the z-value of the endeffector position (mm)
	 */
	double getZ() const;
	void setZ(double z);

	/**
	 * Returns the phi-value of the endeffector position (rad)
	 */
	double getPhi() const;
	void setPhi(double phi);

	/**
	 * Returns the psi-value of the endeffector position (rad)
	 */
	double getPsi() const;
	void setPsi(double psi);

	/**
	 * Returns the theta-value of the endeffector position (rad)
	 */
	double getTheta() const;
	void setTheta(double theta);

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, KatanaPoseData &type);

	KatanaPoseData();

private:
	double x;
	double y;
	double z;
	double theta;
	double phi;
	double psi;
};

}

#endif /* KATANAPOSEDATA_H_ */
