/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#ifndef PRECISEPOLYGON3D_H_
#define PRECISEPOLYGON3D_H_

#include "Type.h"
#include "Point3D.h"
#include "UnitConverter.h"

namespace airobots {

class PrecisePolygon3D: public Type {

public:

	PrecisePolygon3D();
	PrecisePolygon3D(const PrecisePolygon3D &poly);
	virtual ~PrecisePolygon3D();

	static std::string getBaseTag();
	static std::string getTemplate();

	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, PrecisePolygon3D &pol);
	void sanitizeLocation(xmltio::Location &loc) const;

	virtual bool operator==(const PrecisePolygon3D &other) const;

	void addPoint(double x, double y, double z, LengthUnit unit);
	void addPoint(Point3D point);

	Point3D getCentroid();

protected:

	std::vector<Point3D> list;

};

}

#endif /* PRECISEPOLYGON3D_H_ */
