/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * XmltioType.h
 *
 *  Created on: Nov 4, 2009
 *      Author: jwienke
 */

#ifndef XMLTIOTYPE_H_
#define XMLTIOTYPE_H_

#include <string>

#include <xmltio/xmltio.hpp>

namespace airobots {

/**
 * Interface class that describes methods to implement for extracting form and
 * converting to an xmltio document.
 */
class XmltioType {
public:
	XmltioType();
	virtual ~XmltioType();

	// -------- methods to implement in subtypes --------

	/**
	 * Must be provided by all derived classes. See class comment of
	 * <code>Type</code>.
	 */
	static std::string getBaseTag();

	/**
	 * Must be provided by all derived classes. See class comment of
	 * <code>Type</code>.
	 */
	static std::string getTemplate();

	/**
	 * Sanitizes the given location so that it can be used to construct a new
	 * xml representation of this type. Therefore all information in the
	 * template that is not managed by this type is preserved but every
	 * information that could conflict with a new serialization of the type into
	 * this template is removed.
	 *
	 * @param loc the template location to sanitize
	 */
	virtual void sanitizeLocation(xmltio::Location &loc) const = 0;

	/**
	 * Converts this type to xml using the given location. The location must be
	 * interpreted as already being parsed with the base tag for the type.
	 *
	 * @param loc location to serialize in
	 */
	virtual void fillInto(xmltio::Location &loc) const = 0;

	/**
	 * Converts a location containing an xml representation to the given type.
	 *
	 * @param loc location containing the xml representation to extract
	 * @param type type instance to fill in the information found in the xml
	 */
	static void fromLocation(const xmltio::Location &loc, XmltioType &type);

};

}

namespace xmltio {

void convert(const airobots::XmltioType &t, Location &l);

template<class T>
T extract<T>::get() const {
	T t;
	T::fromLocation(loc_, t);
	return t;
}

}

#endif /* XMLTIOTYPE_H_ */
