/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * KinectDataTest.cpp
 *
 *  Created on: Jan 5, 2011
 *      Author: lziegler
 */

#include <boost/test/unit_test.hpp>
#include <boost/test/floating_point_comparison.hpp>

#include <iostream>

#include <sys/time.h>
#include <time.h>
#include <math.h>

#include "btl/KinectData.h"
#include "utils.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

static const double TOLERANCE = 0.0001;

BOOST_AUTO_TEST_SUITE(KinectDataTest)

BOOST_AUTO_TEST_CASE(testSelfCompatibility) {

	try {

		KinectData original;
		original.setTilt(180.0, DEGREE);
		original.setAcceleration(0.0,1.0,2.0);

		original.setGenerator("generator123");
		original.setTimestamp(Timestamp());

		BOOST_REQUIRE_CLOSE(original.getTilt(RADIAN), M_PI, TOLERANCE);

		Location originalLoc(KinectData::getTemplate(), KinectData::getBaseTag());

		originalLoc = original;

		cout << originalLoc.getDocumentText(true) << endl;

		KinectData parsed = extract<KinectData>(originalLoc);

		BOOST_REQUIRE_EQUAL(original.getGenerator(), parsed.getGenerator());
		BOOST_REQUIRE_EQUAL(original.getTimestamp(), parsed.getTimestamp());
		BOOST_REQUIRE_CLOSE(original.getAccelerationX(), parsed.getAccelerationX(), TOLERANCE);
		BOOST_REQUIRE_CLOSE(original.getAccelerationY(), parsed.getAccelerationY(), TOLERANCE);
		BOOST_REQUIRE_CLOSE(original.getAccelerationZ(), parsed.getAccelerationZ(), TOLERANCE);
		BOOST_REQUIRE_CLOSE(original.getTilt(DEGREE), parsed.getTilt(DEGREE), TOLERANCE);
		BOOST_REQUIRE(original == parsed);

	} catch (std::exception &e) {
		BOOST_FAIL(string("Caught exception: ") + e.what());
	}

}

BOOST_AUTO_TEST_CASE(testFileCompatibility) {

	Location fileContents(readFile("KinectData.xml"), KinectData::getBaseTag());
	KinectData parsed = extract<KinectData>(fileContents);

	BOOST_REQUIRE_EQUAL("generator123", parsed.getGenerator());
	BOOST_REQUIRE_EQUAL(253543797, parsed.getTimestamp().getInserted());
	BOOST_REQUIRE_EQUAL(253543712, parsed.getTimestamp().getUpdated());
	BOOST_REQUIRE_CLOSE(180.0, parsed.getTilt(DEGREE), TOLERANCE);
	BOOST_REQUIRE_CLOSE(0.0, parsed.getAccelerationX(), TOLERANCE);
	BOOST_REQUIRE_CLOSE(1.0, parsed.getAccelerationY(), TOLERANCE);
	BOOST_REQUIRE_CLOSE(2.0, parsed.getAccelerationZ(), TOLERANCE);

}

BOOST_AUTO_TEST_SUITE_END()
