/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * Point2DTest.cpp
 *
 *  Created on: Nov 26, 2010
 *      Author: ltwardon
 */

#include <boost/test/unit_test.hpp>
#include <boost/test/floating_point_comparison.hpp>

#include <iostream>

#include <sys/time.h>
#include <time.h>

#include "btl/Point2D.h"
#include "btl/LengthUnit.h"
#include "utils.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

static const double TOLERANCE = 0.0001;

BOOST_AUTO_TEST_SUITE(Point2DTest)

BOOST_AUTO_TEST_CASE(testSelfCompatibility)
{
	try
	{

		Point2D p0(1,2, MILLIMETER, Point2D::GLOBAL);
		Point2D p1(1,2, MILLIMETER, Point2D::GLOBAL);
		Point2D p2(0.1,0.2, MILLIMETER, Point2D::LOCAL);

		BOOST_REQUIRE_EQUAL(p0 == p1, true);
		BOOST_REQUIRE_EQUAL(p1 == p0, true);

		BOOST_REQUIRE_EQUAL(p1 == p2, false);

		BOOST_REQUIRE_CLOSE(p2.getX(MILLIMETER), p2.getX(METER) * 1000, 0.00001);
		BOOST_REQUIRE_CLOSE(p2.getY(MILLIMETER), p2.getY(METER) * 1000, 0.00001);
		BOOST_REQUIRE_CLOSE(p2.getX(MILLIMETER), p2.getX(CENTIMETER) * 10, 0.00001);
		BOOST_REQUIRE_CLOSE(p2.getY(MILLIMETER), p2.getY(CENTIMETER) * 10, 0.00001);

		Location loc(Point2D::getTemplate(), Point2D::getBaseTag());
		loc = p0;

		Point2D p3 = extract<Point2D>(loc);

		BOOST_REQUIRE_EQUAL(p0 == p3, true);

	}
	catch (std::exception e)
	{
		BOOST_FAIL(string("Caught exception: ") + e.what());
	}

}

BOOST_AUTO_TEST_SUITE_END()
