/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data;

import nu.xom.Attribute;
import nu.xom.Element;
import de.unibi.airobots.btl.common.ElementParser;

public class PoseData extends Type {

	private double x = 0;
	private double y = 0;
	private double z = 0;

	/**
	 * Constructor.
	 */
	public PoseData() {
		super();
	}

	public static String getBaseTag() {
		return "currentarmcoord";
	}

	/**
	 * Constructor.
	 */
	public PoseData(double x, double y, double z) {
		super();
		this.x = x;
		this.y = y;
		this.z = z;

	}

	/**
	 * Returns the x-value of the endeffector position (mm)
	 * 
	 * @return x-value of the endeffector position
	 */
	public double getX() {
		return x;
	}

	/**
	 * Sets the x-value of the endeffector position (mm)
	 * 
	 * @param x
	 *            x-value of the endeffector
	 */
	public void setX(double x) {
		this.x = x;
	}

	/**
	 * Returns the y-value of the endeffector position (mm)
	 * 
	 * @return y-value of the endeffector position
	 */
	public double getY() {
		return y;
	}

	/**
	 * Sets the y-value of the endeffector position (mm)
	 * 
	 * @param y
	 *            y-value of the endeffector
	 */
	public void setY(double y) {
		this.y = y;
	}

	/**
	 * Returns the z-value of the endeffector position (mm)
	 * 
	 * @return z-value of the endeffector position
	 */
	public double getZ() {
		return z;
	}

	/**
	 * Sets the z-value of the endeffector position (mm)
	 * 
	 * @param z
	 *            z-value of the endeffector
	 */
	public void setZ(double z) {
		this.z = z;
	}

	public static void fromElement(Element element, PoseData type) {

		Type.fromElement(element, type);

		Element poseElement = element.getFirstChildElement("currentxyz");
		type.setX(ElementParser.getDoubleAttributeValue(poseElement, "x"));
		type.setY(ElementParser.getDoubleAttributeValue(poseElement, "y"));
		type.setZ(ElementParser.getDoubleAttributeValue(poseElement, "z"));
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void fillInto(Element parent) {
		super.fillInto(parent);

		Element poseElement = new Element("currentxyz");
		parent.appendChild(poseElement);
		poseElement.addAttribute(new Attribute("x", String.valueOf(getX())));
		poseElement.addAttribute(new Attribute("y", String.valueOf(getY())));
		poseElement.addAttribute(new Attribute("z", String.valueOf(getZ())));

	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		return "PoseData [x = " + x + ", y = " + y + ", z = " + z + "]";
	}

}
