/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.taskpattern;

import org.apache.log4j.Logger;

import de.unibi.airobots.btl.data.Type;
import de.unibi.airobots.btl.data.taskpattern.TaskPatternStatusTagData.TaskPatternStatus;

/**
 * The base for all TaskPattern.
 * 
 * @author bcarlmey, vrichter
 */
public abstract class TaskPatternBase extends Type {

	private Logger logger = Logger.getLogger(getClass());

	static final String STATUS_TAG = TaskPatternStatus.STATUS.toString();
	static final String ORIGIN_ATT = TaskPatternStatus.origin.toString();
	static final String VALUE_ATT = TaskPatternStatus.value.toString();

	public TaskOriginData origin;
	public TaskStateData value;

	public void setValue(TaskStateData value) {
		this.value = value;
	}

	public void setValue(String value) {
		for (TaskStateData s : TaskStateData.values()) {
			if (s.toString().equals(value)) {
				this.value = s;
				return;
			}
		}
		logger.error("String: " + value + " does not match TaskStateData.");
	}

	public TaskStateData getValue() {
		return value;
	}

	public String getValueString() {
		return value.toString();
	}

	public void setOrigin(TaskOriginData origin) {
		this.origin = origin;
	}

	public void setOrigin(String origin) {
		for(TaskOriginData s : TaskOriginData.values()) {
			if (s.toString().equals(origin)) {
				this.origin = s;
				return;
			}
		}
	}

	public TaskOriginData getOrigin() {
		return origin;
	}

	public String getOriginString() {
		return origin.toString();
	}
}
